Update for 960809.
authorUlrich Drepper <drepper@redhat.com>
Sat, 10 Aug 1996 00:00:16 +0000 (00:00 +0000)
committerUlrich Drepper <drepper@redhat.com>
Sat, 10 Aug 1996 00:00:16 +0000 (00:00 +0000)
Fri Aug  9 17:38:58 1996  Ulrich Drepper  <drepper@cygnus.com>

* sysdeps/unix/sysv/linux/sys/timex.h: Include <sys/time.h> to
get `struct timeval'.
* sysdeps/unix/sysv/linux/sys/acct.h: Get time_t from <time.h>.
* sysdeps/unix/sysv/linux/sys/module.h: Get size_t from <stddef.h>.
* sysdeps/unix/sysv/linux/sys/io.h: Get definition of __P.
* sysdeps/unix/sysv/linux/sys/klog.h: Likewise.
* gmon/sys/gmon.h: Include <sys/types.h> to get u_long.
* sysdeps/unix/sysv/linux/direntry.h: Complete types in
<linux/dirent.h>.
* io/fts.h: Include <sys/types.h> to get dev_t.
Reported by Matthias Urlichs.

* sysdeps/posix/tempname.c [USE_IN_LIBIO]: Don't clear
  _IO_file_flags.  It's the same as _flags.
Reported by Miquel van Smoorenburg <miquels@Q.cistron.nl>.

Wed Aug  7 19:38:47 1996  Andreas Schwab  <schwab@issan.informatik.uni-dortmund.de>

* sysdeps/unix/sysv/linux/m68k/resourcebits.h: Add RLIMIT_AS.

26 files changed:
ChangeLog
INSTALL
Makeconfig
Makefile
configure.in
grp/Makefile
grp/fgetgrent.c
grp/getgrent.c
grp/getgrent_r.c
grp/getgrgid.c
grp/getgrgid_r.c
grp/getgrnam.c
grp/grp.h
manual/maint.texi
nss/Makefile
nss/nss_files/files-pwd.c
pwd/Makefile
pwd/fgetpwent.c
pwd/getpwent.c
pwd/getpwent_r.c
pwd/getpwnam.c
pwd/getpwnam_r.c
pwd/getpwuid.c
pwd/getpwuid_r.c
pwd/pwd.h
sysdeps/unix/sysv/linux/init-first.c

index 6aa81bb..bab55fd 100644 (file)
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,25 @@
+Fri Aug  9 17:38:58 1996  Ulrich Drepper  <drepper@cygnus.com>
+
+       * sysdeps/unix/sysv/linux/sys/timex.h: Include <sys/time.h> to
+       get `struct timeval'.
+       * sysdeps/unix/sysv/linux/sys/acct.h: Get time_t from <time.h>.
+       * sysdeps/unix/sysv/linux/sys/module.h: Get size_t from <stddef.h>.
+       * sysdeps/unix/sysv/linux/sys/io.h: Get definition of __P.
+       * sysdeps/unix/sysv/linux/sys/klog.h: Likewise.
+       * gmon/sys/gmon.h: Include <sys/types.h> to get u_long.
+       * sysdeps/unix/sysv/linux/direntry.h: Complete types in
+       <linux/dirent.h>.
+       * io/fts.h: Include <sys/types.h> to get dev_t.
+       Reported by Matthias Urlichs.
+
+       * sysdeps/posix/tempname.c [USE_IN_LIBIO]: Don't clear
+       _IO_file_flags.  It's the same as _flags.
+       Reported by Miquel van Smoorenburg <miquels@Q.cistron.nl>.
+
+Wed Aug  7 19:38:47 1996  Andreas Schwab  <schwab@issan.informatik.uni-dortmund.de>
+
+       * sysdeps/unix/sysv/linux/m68k/resourcebits.h: Add RLIMIT_AS.
+
 Thu Aug  8 16:17:38 1996  Ulrich Drepper  <drepper@cygnus.com>
 
        * pwd/getpwent.c: Define BUFLEN from NSS_BUFLEN_PASSWD.
diff --git a/INSTALL b/INSTALL
index 25ede5f..581f392 100644 (file)
--- a/INSTALL
+++ b/INSTALL
@@ -163,12 +163,13 @@ build the GNU C library:
      GNU C compiler.  We recommend GCC version 2.7.2 or later; earlier
      versions may have problems.
 
-   * `binutils' 2.6
+   * `binutils' 2.7
 
      Using the GNU `binutils' (assembler, linker, and related tools) is
      preferable when possible, and they are required to build an ELF
-     shared C library.  We recommend `binutils' version 2.6 or later;
-     earlier versions are known to have problems.
+     shared C library.  We recommend `binutils' version 2.7 or later;
+     earlier versions are known to have problems or to not support all
+     architectures.
 
 Supported Configurations
 ------------------------
index 5b4393d..413a253 100644 (file)
@@ -283,7 +283,7 @@ endif
 
 # Default flags to pass the C compiler.
 ifndef default_cflags
-default_cflags := -g
+default_cflags := -g -O
 endif
 
 # Flags to pass the C compiler when assembling preprocessed assembly code
@@ -485,7 +485,7 @@ ifeq (yes,$(build-omitfp))
 object-suffixes += .go
 CFLAGS-.go = -g
 CFLAGS-.o = -g0 -O99 -fomit-frame-pointer
-CFLAGS-.so += $(CFLAGS.o)
+CFLAGS-.so += $(CFLAGS-.o)
 libtype.go = lib%_g.a
 endif
 
index 4b3446f..6f4511a 100644 (file)
--- a/Makefile
+++ b/Makefile
@@ -54,7 +54,7 @@ endif
 subdirs = csu assert ctype db locale intl catgets math setjmp signal stdlib \
          stdio-common $(stdio) malloc string wcsmbs time dirent grp pwd\
          posix io termios resource misc login socket sysvipc gmon gnulib \
-         wctype manual $(sysdep-subdirs) nss elf po $(add-ons)
+         wctype manual shadow $(sysdep-subdirs) nss elf po $(add-ons)
 export subdirs := $(subdirs)   # Benign, useless in GNU make before 3.63.
 
 # The mach and hurd subdirectories have many generated header files which
index 93c2c09..631a035 100644 (file)
@@ -111,7 +111,7 @@ case "$machine" in
 a29k | am29000)        base_machine=a29k machine=a29k ;;
 alpha*)                base_machine=alpha machine=alpha/$machine ;;
 hppa*)         base_machine=hppa machine=hppa/$machine ;;
-i[345]86)      base_machine=i386 machine=i386/$machine ;;
+i[3456]86)     base_machine=i386 machine=i386/$machine ;;
 m680?0)                base_machine=m68k machine=m68k/$machine ;;
 m68k)          base_machine=m68k machine=m68k/m68020 ;;
 m88???)                base_machine=m88k machine=m88k/$machine ;;
index 273b7d1..091d8ba 100644 (file)
@@ -23,7 +23,7 @@ subdir        := grp
 
 routines := fgetgrent initgroups setgroups \
            getgrent getgrgid getgrnam \
-           getgrent_r getgrgid_r getgrnam_r
+           getgrent_r getgrgid_r getgrnam_r fgetgrent_r
 
 tests := testgrp
 
index 38ccd15..95ae2ec 100644 (file)
@@ -16,25 +16,8 @@ License along with the GNU C Library; see the file COPYING.LIB.  If
 not, write to the Free Software Foundation, Inc., 675 Mass Ave,
 Cambridge, MA 02139, USA.  */
 
-#include <stdio.h>
 #include <grp.h>
-
-/* Define a line parsing function using the common code
-   used in the nss_files module.  */
-
-#define STRUCTURE      group
-#define ENTNAME                grent
-struct grent_data {};
-
-#define TRAILING_LIST_MEMBER           gr_mem
-#define TRAILING_LIST_SEPARATOR_P(c)   ((c) == ',')
-#include "../nss/nss_files/files-parse.c"
-LINE_PARSER
-(,
- STRING_FIELD (result->gr_name, ISCOLON, 0);
- STRING_FIELD (result->gr_passwd, ISCOLON, 0);
- INT_FIELD (result->gr_gid, ISCOLON, 0, 10,);
- )
+#include <stdio.h>
 
 
 /* Read one entry from the given stream.  */
@@ -43,21 +26,6 @@ fgetgrent (FILE *stream)
 {
   static char buffer[BUFSIZ];
   static struct group result;
-  char *p;
-
-  do
-    {
-      p = fgets (buffer, sizeof buffer, stream);
-      if (p == NULL)
-       return NULL;
-
-      /* Skip leading blanks.  */
-      while (isspace (*p))
-       ++p;
-    } while (*p == '\0' || *p == '#' ||        /* Ignore empty and comment lines.  */
-            /* Parse the line.  If it is invalid, loop to
-               get the next line of the file to parse.  */
-            ! parse_line (p, &result, (void *) buffer, sizeof buffer));
 
-  return &result;
+  return __fgetgrent_r (stream, &result, buffer, sizeof buffer);
 }
index 4e14bbc..d19e4d1 100644 (file)
@@ -25,6 +25,6 @@ Boston, MA 02111-1307, USA.  */
 #define        GETFUNC_NAME    getgrent
 #define        ENDFUNC_NAME    endgrent
 #define DATABASE_NAME  group
-#define BUFLEN         1024
+#define BUFLEN         NSS_BUFLEN_GROUP
 
 #include "../nss/getXXent.c"
index db692b2..1f60763 100644 (file)
@@ -25,6 +25,6 @@ Boston, MA 02111-1307, USA.  */
 #define        GETFUNC_NAME    getgrent
 #define        ENDFUNC_NAME    endgrent
 #define DATABASE_NAME  group
-#define BUFLEN         1024
+#define BUFLEN         NSS_BUFLEN_GROUP
 
 #include "../nss/getXXent_r.c"
index 855d31c..b90000b 100644 (file)
@@ -25,6 +25,6 @@ Boston, MA 02111-1307, USA.  */
 #define DATABASE_NAME  group
 #define ADD_PARAMS     gid_t gid
 #define ADD_VARIABLES  gid
-#define BUFLEN         1024
+#define BUFLEN         NSS_BUFLEN_GROUP
 
 #include "../nss/getXXbyYY.c"
index 3b1719d..6c7704d 100644 (file)
@@ -25,6 +25,6 @@ Boston, MA 02111-1307, USA.  */
 #define DATABASE_NAME  group
 #define ADD_PARAMS     gid_t gid
 #define ADD_VARIABLES  gid
-#define BUFLEN         1024
+#define BUFLEN         NSS_BUFLEN_GROUP
 
 #include "../nss/getXXbyYY_r.c"
index 2104d87..f060ea9 100644 (file)
@@ -25,6 +25,6 @@ Boston, MA 02111-1307, USA.  */
 #define DATABASE_NAME  group
 #define ADD_PARAMS     const char *name
 #define ADD_VARIABLES  name
-#define BUFLEN         1024
+#define BUFLEN         NSS_BUFLEN_GROUP
 
 #include "../nss/getXXbyYY.c"
index 1abe22e..6a88191 100644 (file)
--- a/pwd/pwd.h
+++ b/pwd/pwd.h
@@ -123,6 +123,17 @@ extern struct passwd *getpwnam_r __P ((__const char *__name,
                                       struct passwd *__resultbuf,
                                       char *__buffer, int __buflen));
 
+
+#ifdef __USE_SVID
+/* Read an entry from STREAM.  */
+extern struct passwd *__fgetpwent_r __P ((FILE * __stream,
+                                         struct passwd *__resultbuf,
+                                         char *__buffer, int __buflen));
+extern struct passwd *fgetpwent_r __P ((FILE * __stream,
+                                       struct passwd *__resultbuf,
+                                       char *__buffer, int __buflen));
+#endif
+
 #endif /* reentrant */
 
 
index aa7d9c4..267c01a 100644 (file)
@@ -43,6 +43,10 @@ init (void *data)
   char **argv = (char **)data + 1;
   char **envp = &argv[argc + 1];
 
+  /* XXX Another gcc bug.  We marked the function as `unused' but it
+     is still optimized away.  */
+  volatile void *foo __attribute__ ((unused)) = &init;
+
 #ifdef PIC
   if (&__libc_is_static != NULL)
 #endif
--- a/grp/grp.h
+++ b/grp/grp.h
@@ -110,6 +110,16 @@ extern struct group *getgrnam_r __P ((__const char *__name,
                                      struct group *__resultbuf,
                                      char *buffer, int __buflen));
 
+#ifdef __USE_SVID
+/* Read a group entry from STREAM.  */
+extern struct group *__fgetgrent_r __P ((FILE * __stream,
+                                        struct group *__resultbuf,
+                                        char *buffer, int __buflen));
+extern struct group *fgetgrent_r __P ((FILE * __stream,
+                                      struct group *__resultbuf,
+                                      char *buffer, int __buflen));
+#endif
+
 #endif /* reentrant */
 
 
index 98467e4..cd6c996 100644 (file)
@@ -206,12 +206,12 @@ compiler.  We recommend GCC version 2.7.2 or later; earlier versions may
 have problems.
 
 @item
-@code{binutils} 2.6
+@code{binutils} 2.7
 
 Using the GNU @code{binutils} (assembler, linker, and related tools) is
 preferable when possible, and they are required to build an ELF shared C
-library.  We recommend @code{binutils} version 2.6 or later; earlier
-versions are known to have problems.
+library.  We recommend @code{binutils} version 2.7 or later; earlier
+versions are known to have problems or to not support all architectures.
 @end itemize
 
 @node Supported Configurations
index aafa8e2..f23f5f3 100644 (file)
@@ -28,7 +28,8 @@ distribute            := nsswitch.h XXX-lookup.c getXXbyYY.c getXXbyYY_r.c \
 routines               = nsswitch $(addsuffix -lookup,$(databases))
 
 # These are the databases that go through nss dispatch.
-databases              = proto service hosts network grp pwd rpc ethers
+databases              = proto service hosts network grp pwd rpc ethers \
+                         spwd
 
 # Specify rules for the nss_* modules.  We have some services.
 services               := files dns db
index 9732bc6..a778d01 100644 (file)
@@ -24,7 +24,7 @@ Cambridge, MA 02139, USA.  */
 #define DATABASE       "passwd"
 struct pwent_data {};
 
/* Our parser function is already defined in fgetpwent.c, so use that
    to parse lines from the database file.  */
 #define EXTERN_PARSER
 #include "files-parse.c"
index ce67d49..68cdc4a 100644 (file)
@@ -23,6 +23,6 @@ subdir        := pwd
 
 routines := fgetpwent getpw putpwent \
            getpwent getpwnam getpwuid \
-           getpwent_r getpwnam_r getpwuid_r
+           getpwent_r getpwnam_r getpwuid_r fgetpwent_r
 
 include ../Rules
index f8548fe..215d6e0 100644 (file)
@@ -16,27 +16,8 @@ License along with the GNU C Library; see the file COPYING.LIB.  If
 not, write to the Free Software Foundation, Inc., 675 Mass Ave,
 Cambridge, MA 02139, USA.  */
 
-#include <stdio.h>
 #include <pwd.h>
-
-/* Define a line parsing function using the common code
-   used in the nss_files module.  */
-
-#define STRUCTURE      passwd
-#define ENTNAME                pwent
-struct pwent_data {};
-
-#include "../nss/nss_files/files-parse.c"
-LINE_PARSER
-(,
- STRING_FIELD (result->pw_name, ISCOLON, 0);
- STRING_FIELD (result->pw_passwd, ISCOLON, 0);
- INT_FIELD (result->pw_uid, ISCOLON, 0, 10,);
- INT_FIELD (result->pw_gid, ISCOLON, 0, 10,);
- STRING_FIELD (result->pw_gecos, ISCOLON, 0);
- STRING_FIELD (result->pw_dir, ISCOLON, 0);
- result->pw_shell = line;
- )
+#include <stdio.h>
 
 
 /* Read one entry from the given stream.  */
@@ -45,21 +26,6 @@ fgetpwent (FILE *stream)
 {
   static char buffer[BUFSIZ];
   static struct passwd result;
-  char *p;
-
-  do
-    {
-      p = fgets (buffer, sizeof buffer, stream);
-      if (p == NULL)
-       return NULL;
-
-      /* Skip leading blanks.  */
-      while (isspace (*p))
-       ++p;
-    } while (*p == '\0' || *p == '#' ||        /* Ignore empty and comment lines.  */
-            /* Parse the line.  If it is invalid, loop to
-               get the next line of the file to parse.  */
-            ! parse_line (p, &result, (void *) buffer, sizeof buffer));
 
-  return &result;
+  return __fgetpwent_r (stream, &result, buffer, sizeof buffer);
 }
index 79edbd5..9b96c63 100644 (file)
@@ -25,6 +25,6 @@ Boston, MA 02111-1307, USA.  */
 #define        GETFUNC_NAME    getpwent
 #define        ENDFUNC_NAME    endpwent
 #define DATABASE_NAME  passwd
-#define BUFLEN         1024
+#define BUFLEN         NSS_BUFLEN_PASSWD
 
 #include "../nss/getXXent.c"
index ced7f8a..1c5bc02 100644 (file)
@@ -8,7 +8,7 @@ published by the Free Software Foundation; either version 2 of the
 License, or (at your option) any later version.
 
 The GNU C Library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
+but WITHOUT ANY WARRANTY; without even the implied warranty of/tes
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
@@ -25,6 +25,6 @@ Boston, MA 02111-1307, USA.  */
 #define        GETFUNC_NAME    getpwent
 #define        ENDFUNC_NAME    endpwent
 #define DATABASE_NAME  passwd
-#define BUFLEN         1024
+#define BUFLEN         NSS_BUFLEN_PASSWD
 
 #include "../nss/getXXent_r.c"
index 597b8d1..042fdae 100644 (file)
@@ -25,6 +25,6 @@ Boston, MA 02111-1307, USA.  */
 #define DATABASE_NAME  passwd
 #define ADD_PARAMS     const char *name
 #define ADD_VARIABLES  name
-#define BUFLEN         1024
+#define BUFLEN         NSS_BUFLEN_PASSWD
 
 #include "../nss/getXXbyYY.c"
index c2d1f84..93fadc5 100644 (file)
@@ -25,6 +25,6 @@ Boston, MA 02111-1307, USA.  */
 #define DATABASE_NAME  passwd
 #define ADD_PARAMS     const char *name
 #define ADD_VARIABLES  name
-#define BUFLEN         1024
+#define BUFLEN         NSS_BUFLEN_PASSWD
 
 #include "../nss/getXXbyYY_r.c"
index 130c251..2ad654f 100644 (file)
@@ -25,6 +25,6 @@ Boston, MA 02111-1307, USA.  */
 #define DATABASE_NAME  passwd
 #define ADD_PARAMS     uid_t uid
 #define ADD_VARIABLES  uid
-#define BUFLEN         1024
+#define BUFLEN         NSS_BUFLEN_PASSWD
 
 #include "../nss/getXXbyYY.c"
index e3bf757..8e92ee2 100644 (file)
@@ -25,6 +25,6 @@ Boston, MA 02111-1307, USA.  */
 #define DATABASE_NAME  passwd
 #define ADD_PARAMS     uid_t uid
 #define ADD_VARIABLES  uid
-#define BUFLEN         1024
+#define BUFLEN         NSS_BUFLEN_PASSWD
 
 #include "../nss/getXXbyYY_r.c"
index 0023509..9bd380a 100644 (file)
@@ -24,7 +24,7 @@ Cambridge, MA 02139, USA.  */
 struct pwent_data {};
 
-/* Our parser function is already defined in fgetpwent.c, so use that
+/* Our parser function is already defined in fgetpwent_r.c, so use that
    to parse lines from the database file.  */
 #define EXTERN_PARSER